Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_probing_strategies.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_probing_strategies.hh')
-rw-r--r--source/blender/blenlib/BLI_probing_strategies.hh8
1 files changed, 4 insertions, 4 deletions
diff --git a/source/blender/blenlib/BLI_probing_strategies.hh b/source/blender/blenlib/BLI_probing_strategies.hh
index 9fa402d4244..29ebe28aff9 100644
--- a/source/blender/blenlib/BLI_probing_strategies.hh
+++ b/source/blender/blenlib/BLI_probing_strategies.hh
@@ -21,8 +21,8 @@
* \ingroup bli
*
* This file implements different probing strategies. Those can be used by different hash table
* implementations like BLI::Set and BLI::Map. A probing strategy produces a sequence of values
* based on an initial hash value.
*
* A probing strategy has to implement the following methods:
* - Constructor(uint32_t hash): Start a new probing sequence based on the given hash.
@@ -56,7 +56,7 @@
#include "BLI_sys_types.h"
-namespace BLI {
+namespace blender {
/**
* The simplest probing strategy. It's bad in most cases, because it produces clusters in the hash
@@ -245,6 +245,6 @@ using DefaultProbingStrategy = PythonProbingStrategy<>;
// clang-format on
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_PROBING_STRATEGIES_HH__ */
@@ -21,8 +21,8 @@
*
* This file implements different probing strategies. Those can be used by different hash table
- * implementations like BLI::Set and BLI::Map. A probing strategy produces a sequence of values
- * based on an initial hash value.
+ * implementations like blender::Set and blender::Map. A probing strategy produces a sequence of
+ * values based on an initial hash value.
*
* A probing strategy has to implement the following methods: